@@ -18,10 +18,7 @@ limitations under the License.
 
 from django.contrib import admin
 
-from .models import (
-   Repository,
-   Image
-)
+from .models import Repository, Image
 
 
 @admin.register(Repository)
