@@ -18,6 +18,12 @@ limitations under the License.
 
 from django.apps import AppConfig
 
+
 class DjangoOciConfig(AppConfig):
-    name = 'django_oci'
-    verbose_name = 'Opencontainer Distribution specification for Django'
+    name = "django_oci"
+    verbose_name = "Opencontainer Distribution specification for Django"
+
+    def ready(self):
+        import django_oci.signals
+
+        assert django_oci.signals
